<?php


namespace Drupal\healthcheck\Plugin\healthcheck;


use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\healthcheck\Finding\Finding;
use Drupal\healthcheck\Finding\Report;
use Drupal\healthcheck\Plugin\HealthcheckPluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * @Healthcheck(
 *  id = "cron",
 *  label = @Translation("Cron"),
 *  description = "Checks when cron was last run.",
 *  tags = {
 *   "performance",
 *  }
 * )
 */
class Cron extends HealthcheckPluginBase implements ContainerFactoryPluginInterface {

  use StringTranslationTrait;

  /**
   * The state service
   */
  protected $stateSrv;

  /**
   * CacheBackend constructor.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, $finding_service, $state_srv) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $finding_service);
    $this->stateSrv = $state_srv;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('healthcheck.finding'),
      $container->get('state')
    );
  }

  public function getFindings() {
    $findings = [];
    $now = \Drupal::time()->getRequestTime();
    $key = 'cron_last';

    $last_cron_run = $this->stateSrv->get('system.cron_last');
    $cron_offset = $now - $last_cron_run;

    if ($cron_offset < 15 * 60) {
      $findings[] = $this->needsReview($key);
    }
    elseif ($cron_offset < 24 * 60 * 60) {
      $findings[] = $this->actionRequested($key);
    }
    else {
      $findings[] = $this->critical($key);
    }

    return $findings;
  }

}
