<?php


namespace Drupal\healthcheck\Plugin\healthcheck;


use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\healthcheck\Finding\Finding;
use Drupal\healthcheck\Finding\Report;
use Drupal\healthcheck\Plugin\HealthcheckPluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * @Healthcheck(
 *  id = "php_errors",
 *  label = @Translation("PHP Errors"),
 *  description = "Checks the database log for PHP errors.",
 *  tags = {
 *   "performance",
 *  }
 * )
 */
class PhpErrors extends HealthcheckPluginBase implements ContainerFactoryPluginInterface {

  use StringTranslationTrait;

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  /**
   * The Module Handler
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * CacheBackend constructor.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, $finding_service, $database, $module_handler) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $finding_service);
    $this->database = $database;
    $this->moduleHandler = $module_handler;

  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('healthcheck.finding'),
      $container->get('database'),
      $container->get('module_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFindings() {
    $findings = [];

    if ($this->moduleHandler->moduleExists('dblog')) {
      $findings[] = $this->checkLogs();
    }
    else {
      $findings[] = $this->notPerformed($this->getPluginId());
    }

    return $findings;
  }

  protected function checkLogs() {
    $now = time();

    $threshold = $now - (60 * 60 * 24);

    $query = $this->database->select('watchdog', 'wd');

    $query->addExpression('COUNT(wid)');

    $query->condition('wd.type', 'php');

    $query->condition('wd.timestamp', $threshold, '>');

    $result = $query->execute()->fetchField();

    if (empty($result)) {
      return $this->noActionRequired($this->getPluginId());
    }

    return $this->actionRequested($this->getPluginId(), [
      ':count' => $result,
    ]);
  }
}
